@@ -500,7 +500,7 @@ async def async_zip(
         pass
 
 
-class async_chain[T](AsyncIterable):
+class async_chain[T](AsyncIterator):
 
     def __init__(
         self, 
@@ -508,21 +508,29 @@ class async_chain[T](AsyncIterable):
         *iterables: Iterable[T] | AsyncIterable[T], 
         threaded: bool = False, 
     ):
-        self.iterables = (ensure_aiter(it, threaded=threaded) for it in iterables)
+        self._anext = type(self).from_iterable(iterables, threaded=threaded).__anext__
 
-    async def __aiter__(self, /) -> AsyncIterator[T]:
-        for iterable in self.iterables:
-            async for e in iterable:
-                yield e
+    def __aiter__(self, /) -> Self:
+        return self
+
+    def __anext__(self, /) -> Awaitable[T]:
+        return self._anext()
 
     @classmethod
-    def from_iterable(
+    async def from_iterable(
         cls, 
         /, 
-        iterables: Iterable[Iterable[T] | AsyncIterable[T]], 
+        iterables: Iterable[Iterable[T] | AsyncIterable[T]] | AsyncIterable[Iterable[T] | AsyncIterable[T]], 
         threaded: bool = False, 
-    ) -> async_chain:
-        return cls(*iterables, threaded=threaded)
+    ) -> AsyncIterator[T]:
+        if isinstance(iterables, Iterable):
+            for iterable in iterables:
+                async for e in ensure_aiter(iterable, threaded=threaded):
+                    yield e
+        else:
+            async for iterable in iterables:
+                async for e in ensure_aiter(iterable, threaded=threaded):
+                    yield e
 
 
 async def async_all(
